@@ -44,7 +44,8 @@ BEGIN
 
     # Pg
     european_dates     => { type => 'boolean', method_spec => { default => 0 } },
-
+    pg_enable_utf8     => { type => 'boolean' },
+    
     # SQLite
     auto_create => { type => 'boolean', method_spec => { default => 1 } },
 
@@ -520,6 +521,14 @@ Get or set the boolean value that determines whether or not dates are assumed to
 
 This value will be passed to L<DateTime::Format::Pg> as the value of the C<european> parameter in the call to the constructor C<new()>.  This L<DateTime::Format::Pg> object is used by L<Rose::DB::Pg> to parse and format date-related column values in methods like L<parse_date|Rose::DB/parse_date>, L<format_date|Rose::DB/format_date>, etc.
 
+=item B<pg_enable_utf8 [BOOL]>
+
+Get or set the L<pg_enable_utf8|DBD::Pg/pg_enable_utf8> database handle attribute.  This is set directly on the L<dbh|Rose::DB/dbh>, if one exists.  Otherwise, it will be set when the L<dbh|Rose::DB/dbh> is created.  If no value for this attribute is defined (the default) then it will not be set when the L<dbh|Rose::DB/dbh> is created, deferring instead to whatever default value L<DBD::Pg> chooses.
+
+Returns the value of this attribute in the L<dbh|Rose::DB/dbh>, if one exists, or the value that will be set when the L<dbh|Rose::DB/dbh> is next created.
+
+See the L<DBD::Pg|DBD::Pg/pg_enable_utf8> documentation to learn more about this attribute.
+
 =back
 
 =head3 SQLite
@@ -542,6 +551,6 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2008 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
